@@ -11,21 +11,16 @@ Support for the Microsoft Access database.
 
 
 """
-from sqlalchemy import sql, schema, types, exc, pool
-from sqlalchemy.sql import compiler, expression
-from sqlalchemy.sql.compiler import OPERATORS
-from sqlalchemy.sql.operators import ne, is_, isnot
-from sqlalchemy.engine import default, base, reflection
-from sqlalchemy import processors
+from sqlalchemy import types, exc, pool
+from sqlalchemy.sql import compiler
+from sqlalchemy.engine import default, reflection
 
 import pyodbc
 
-# The != operator override is required in order to make
-# the AccessCompiler class correctly format emitted queries
-OPERATORS[ne] =  " <> "
-
 
 # AutoNumber
+
+
 class COUNTER(types.Integer):
     __visit_name__ = "COUNTER"
 
@@ -142,24 +137,19 @@ class AccessCompiler(compiler.SQLCompiler):
 
     def get_select_precolumns(self, select, **kw):
         # (plagiarized from mssql/base.py)
+
+        s = super(AccessCompiler, self).get_select_precolumns(select, **kw)
+
         """ Access puts TOP, it's version of LIMIT here """
-
-        s = ""
-        if select._distinct:
-            s += "DISTINCT "
-
-        if select._simple_int_limit and not select._offset:
+        if select._offset:
+            raise NotImplementedError("Access SQL does not support OFFSET")
+        elif select._simple_int_limit:
             # ODBC drivers and possibly others
             # don't support bind params in the SELECT clause on SQL Server.
             # so have to use literal here.
             s += "TOP %d " % select._limit
 
-        if s:
-            return s
-        else:
-            return compiler.SQLCompiler.get_select_precolumns(
-                self, select, **kw
-            )
+        return s
 
     def limit_clause(self, select, **kw):
         """Limit in access is after the select keyword"""
@@ -227,6 +217,12 @@ class AccessCompiler(compiler.SQLCompiler):
         stmt = "SELECT %s FROM USysSQLAlchemyDUAL WHERE 1=0" % literal
         return stmt
 
+    def visit_ne_binary(self, binary, operator, **kw):
+        return "%s <> %s" % (
+            self.process(binary.left),
+            self.process(binary.right),
+        )
+
 
 class AccessTypeCompiler(compiler.GenericTypeCompiler):
     def visit_big_integer(self, type_, **kw):
@@ -301,6 +297,9 @@ class AccessDDLCompiler(compiler.DDLCompiler):
 
 
 class AccessIdentifierPreparer(compiler.IdentifierPreparer):
+    illegal_initial_characters = compiler.ILLEGAL_INITIAL_CHARACTERS.copy()
+    illegal_initial_characters.update(["_"])
+
     reserved_words = compiler.RESERVED_WORDS.copy()
     # https://support.office.com/en-us/article/learn-about-access-reserved-words-and-symbols-ae9d9ada-3255-4b12-91a9-f855bdd9c5a2
     reserved_words.update(
